@@ -1,6 +1,6 @@
 package Dist::Zilla::MintingProfile::Author::BBYRD;
 
-our $VERSION = '0.96'; # VERSION
+our $VERSION = '0.97'; # VERSION
 # ABSTRACT: DZIL MintingProfile for BBYRD
 
 use sanity;
@@ -55,10 +55,6 @@ site near you, or see L<https://metacpan.org/module/Dist::Zilla::PluginBundle::A
 
 Brendan Byrd <BBYRD@CPAN.org>
 
-=head1 CONTRIBUTOR
-
-Brendan Byrd <Perl@ResonatorSoft.org>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by Brendan Byrd.
